use 5.006;
use strict;
use warnings;
use Test::More tests => 1;

use IO::File;

pass;

#
# This file is part of Dist-Zilla-Plugin-Prereqs-AuthorDeps
#
# This software is Copyright (c) 2013 by David Golden.
#
# This is free software, licensed under:
#
#   The Apache License, Version 2.0, January 2004
#
